OC.L10N.register(
    "files_versions",
    {
    "Versions" : "Εκδόσεις",
    "This application automatically maintains older versions of files that are changed." : "Η εφαρμογή διατηρεί αυτόματα παλαιότερες εκδόσεις των αρχείων που έχουν αλλάξει.",
    "Failed to revert {file} to revision {timestamp}." : "Αποτυχία επαναφοράς του {file} στην αναθεώρηση {timestamp}.",
    "_%n byte_::_%n bytes_" : ["%n bytes","%n bytes"],
    "Restore" : "Επαναφορά",
    "No other versions available" : "Δεν υπάρχουν άλλες εκδόσεις διαθέσιμες"
},
"nplurals=2; plural=(n != 1);");
